/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file hourglass.h
 *
 * @type helper
 *
 * @description
 *
 * The hourglass helper provides an interface to the Hourglass module.
 */

#ifndef __rov_hourglass
#define __rov_hourglass


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Turn the hourglass on.
 * @see hourglass_start()
 */
void hourglass_on(void);

/**
 * Turn the hourglass off.
 * @note The hourglass maintains a count of the number of on and off calls.
 * This means that if you want to turn the hourglass off, you must call
 * hourglass_off() the same number of times as hourglass_on(). If you need
 * to forcibly turn the hourglass off, call hourglass_smash().
 * @see hourglass_smash()
 */
void hourglass_off(void);

/**
 * Set the hourglass to a percentage.
 * @param percent the value (0 to 100)
 */
void hourglass_percentage(int percent);

/**
 * Forcibly smash the hourglass.
 * @see hourglass_off()
 */
void hourglass_smash(void);

/**
 * Start the hourglass after a delay.
 * @param delay the time to delay in centiseconds.
 */
void hourglass_start(int delay);

/**
 * Set the hourglass LED state.
 * @param state the LED state.
 * @see hourglass_on()
 */
void hourglass_leds(int state);


#ifdef __cplusplus
}
#endif

#endif
